%define pkgname		libglade
%define api_version	2.0
%define api_major_version 2
%define lib_major	0
%define lib_name	%mklibname glade %{api_version} %{lib_major}

Summary:	Library for dynamically loading GLADE interface files
Name:		%{pkgname}%{api_version}
Version:	2.6.4
Release:	%mkrel 18
License:	LGPLv2+
Group:		System/Libraries
URL:		https://www.gnome.org/
Source0:	https://download.gnome.org/sources/%{pkgname}/%{pkgname}-%{version}.tar.bz2
# (fc) fix some warnings (Fedora) (GNOME bug #121025)
Patch0:		libglade-2.0.1-nowarning.patch
BuildConflicts:	libglade0-devel < 0.17
BuildRequires:	autoconf
BuildRequires:	pkgconfig(atk) >= 1.9.0
BuildRequires:	pkgconfig(glib-2.0) >= 2.10.0
BuildRequires:	pkgconfig(gtk+-2.0) >= 2.5.0
BuildRequires:	pkgconfig(libxml-2.0) >= 2.4.10
BuildRequires:	python3
BuildRequires:  gtk-doc

%description
%{pkgname} allows you to load user interfaces in your program, which are
stored externally.  This allows alteration of the interface without
recompilation of the program.


%package -n %{lib_name}
Summary:	%{summary}
Group:		%{group}
Provides:	%{pkgname}%{api_version} = %{version}-%{release}

%description -n %{lib_name}
%{pkgname} allows you to load user interfaces in your program, which are
stored externally.  This allows alteration of the interface without
recompilation of the program.


%package -n %{lib_name}-devel
Summary:	Libraries, includes, etc to develop libglade applications
Group:		Development/GNOME and GTK+
Conflicts:	libglade0-devel < 0.17
Provides:	%{pkgname}%{api_version}-devel = %{version}-%{release}
Provides:	%{pkgname}%{api_major_version}-devel = %{version}-%{release}
Requires:	%{lib_name} = %{version}-%{release}
Requires(post):     sgml-common
Requires(postun):     sgml-common


%description -n %{lib_name}-devel
%{pkgname} allows you to load user interfaces in your program, which are
stored externally.  This allows alteration of the interface without
recompilation of the program.

This package contains static libraries, include files, etc so that
you can use to develop %{pkgname} applications.


%prep
%setup -q -n %{pkgname}-%{version}
%autopatch -p1

%build
# to recognize aarch64
autoreconf -vfi

%configure --disable-static
%make_build

%install
%make_install

find %{buildroot} -name '*.la' -delete

# install test program
sh ./libtool --mode=install %{_bindir}/install test-libglade %{buildroot}%{_bindir}/test-libglade

mkdir -p %{buildroot}%{_libdir}/libglade/%{api_version}

# python2 only and not really needed and useful since some years
rm -rf %{buildroot}%{_bindir}/libglade-convert

%post -n %{lib_name}-devel
CATALOG=/etc/xml/catalog
%{_bindir}/xmlcatalog --noout --add "system" \
		"http://glade.gnome.org/glade-2.0.dtd" \
		%{_datadir}/xml/libglade/glade-2.0.dtd $CATALOG || true

%postun -n %{lib_name}-devel
# Do not remove if upgrade
if [ "$1" = "0" ]; then
 CATALOG=/etc/xml/catalog
 if [ -f $CATALOG -a -x %{_bindir}/xmlcatalog ]; then 
  %{_bindir}/xmlcatalog --noout --del \
         	%{_datadir}/xml/libglade/glade-2.0.dtd $CATALOG || true
 fi
fi

%files -n %{lib_name}
%doc README ChangeLog
%{_libdir}/lib*.so.%{lib_major}
%{_libdir}/lib*.so.%{lib_major}.*
%dir %{_libdir}/libglade
%dir %{_libdir}/libglade/%{api_version}

%files -n %{lib_name}-devel
%doc AUTHORS examples
%doc %{_datadir}/gtk-doc/html/*
%{_bindir}/*
%{_datadir}/xml/libglade
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*


%changelog
* Sun Mar 16 2025 wally <wally> 2.6.4-18.mga10
+ Revision: 2164895
- rebuild for libxml2 2.13.6

* Tue Mar 29 2022 umeabot <umeabot> 2.6.4-17.mga9
+ Revision: 1831924
- Mageia 9 Mass Rebuild

* Tue Feb 02 2021 daviddavid <daviddavid> 2.6.4-16.mga8
+ Revision: 1674541
- drop no more needed and python2 only libglade-convert binary

* Wed Aug 05 2020 joequant <joequant> 2.6.4-15.mga8
+ Revision: 1611083
- add deps
+ danf <danf>
- Switch URLs from http: to https:

* Thu Feb 13 2020 daviddavid <daviddavid> 2.6.4-14.mga8
+ Revision: 1514122
- fix python shebangs
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 2.6.4-13.mga7
+ Revision: 1298871
- Mageia 7 Mass Rebuild

* Sun Jun 03 2018 wally <wally> 2.6.4-12.mga7
+ Revision: 1233984
- fix build on aarch64
+ kekepower <kekepower>
- Use new make macros

* Sat Feb 06 2016 umeabot <umeabot> 2.6.4-11.mga6
+ Revision: 940485
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2.6.4-10.mga5
+ Revision: 747408
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.6.4-9.mga5
+ Revision: 681489
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 2.6.4-8.mga4
+ Revision: 507035
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 2.6.4-7.mga3
+ Revision: 357226
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Sep 14 2011 fwang <fwang> 2.6.4-6.mga3
+ Revision: 143205
- update libdir
- drop .la files
- drop .la files

* Wed Jan 12 2011 blino <blino> 2.6.4-5.mga1
+ Revision: 6571
- remove old version checks for post scriptlets
- remove version in comment
- remove old ldconfig scriptlets
- imported package libglade2.0


* Sun Nov 28 2010 Oden Eriksson <oeriksson@mandriva.com> 2.6.4-4mdv2011.0
+ Revision: 602551
- rebuild

* Tue Mar 16 2010 Oden Eriksson <oeriksson@mandriva.com> 2.6.4-3mdv2010.1
+ Revision: 520826
- rebuilt for 2010.1

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 2.6.4-2mdv2010.0
+ Revision: 425548
- rebuild

* Tue Mar 17 2009 Götz Waschk <waschk@mandriva.org> 2.6.4-1mdv2009.1
+ Revision: 356642
- update to new version 2.6.4

* Tue Aug 19 2008 Götz Waschk <waschk@mandriva.org> 2.6.3-1mdv2009.0
+ Revision: 273545
- new version
- drop patch 1
- update license

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 2.6.2-7mdv2009.0
+ Revision: 222595
- rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Wed Mar 26 2008 Emmanuel Andry <eandry@mandriva.org> 2.6.2-6mdv2008.1
+ Revision: 190525
- Fix lib group

* Thu Feb 21 2008 Frederic Crozat <fcrozat@mandriva.com> 2.6.2-5mdv2008.1
+ Revision: 173657
- Patch1 (SVN): fix invalmid call to g_free

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Fri Sep 21 2007 David Walluck <walluck@mandriva.org> 2.6.2-3mdv2008.0
+ Revision: 92091
- add devel provides for fc compat

* Wed Aug 15 2007 Adam Williamson <awilliamson@mandriva.org> 2.6.2-2mdv2008.0
+ Revision: 63596
- fix autoconf buildrequires
- drop manual dependency on libxml2, it has an auto-generated one anyway

* Tue Jul 31 2007 Götz Waschk <waschk@mandriva.org> 2.6.2-1mdv2008.0
+ Revision: 56919
- new version

* Tue Jun 19 2007 Götz Waschk <waschk@mandriva.org> 2.6.1-1mdv2008.0
+ Revision: 41348
- new version


* Thu Nov 30 2006 Götz Waschk <waschk@mandriva.org> 2.6.0-2mdv2007.0
+ Revision: 88961
- Import libglade2.0

* Thu Nov 30 2006 Götz Waschk <waschk@mandriva.org> 2.6.0-2mdv2007.1
- unpack patch

* Thu Jul 13 2006 Götz Waschk <waschk@mandriva.org> 2.6.0-1mdv2007.0
- drop patch 1
- New release 2.6.0

* Sat Apr 15 2006 Frederic Crozat <fcrozat@mandriva.com> 2.5.1-3mdk
- Patch0 (Fedora): fix some warnings (GNOME bug #121025)
- Patch1 (CVS): make non-ASCII invisible characters work (GNOME bug #321119)

* Wed Oct 12 2005 Frederic Crozat <fcrozat@mandriva.com> 2.5.1-2mdk
- replace prereq with new syntax
- Rebuild to get debug package

* Wed Apr 20 2005 Frederic Crozat <fcrozat@mandriva.com> 2.5.1-1mdk 
- Release 2.5.1 (based on Götz Waschk package)

* Sat Feb 12 2005 Götz Waschk <waschk@linux-mandrake.com> 2.4.2-1mdk
- drop merged patch
- New release 2.4.2

* Fri Feb 11 2005 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.1-2mdk 
- Patch0 (CVS): fix regressions (Mdk bug #12574)

* Mon Nov 29 2004 Götz Waschk <waschk@linux-mandrake.com> 2.4.1-1mdk
- reenable libtoolize
- drop patch
- New release 2.4.1

* Fri Sep 24 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.4.0-2mdk
- Patch0 (CVS): fix accelerator not set when using stock entries

* Tue May 18 2004 Götz Waschk <waschk@linux-mandrake.com> 2.4.0-1mdk
- fix source URL
- New release 2.4.0

* Tue Apr 06 2004 Frederic Crozat <fcrozat@mandrakesoft.com> 2.3.6-1mdk
- Release 2.3.6 (with Götz Waschk help)
- requires new glib2
- fix doc list
- requires new gtk
- don't run libtoolize
- don't regenerate the auto* stuff

